%define oname	pwquality

%define major	1
%define libname %mklibname %{oname} %{major}
%define devname	%mklibname %{oname} -d

Summary:	Library for password quality checking and generating random passwords
Name:		libpwquality
Version:	1.4.5
Release:	%mkrel 4
# The package is BSD licensed with option to relicense as GPL+
# - this option is redundant as the BSD license allows that anyway.
License:	BSD or GPL+
Group:		System/Libraries
URL:		https://github.com/libpwquality/libpwquality/
Source0:	https://github.com/libpwquality/libpwquality/releases/download/libpwquality-%{version}/libpwquality-%{version}.tar.bz2
# Use setuptools instead of distutils
# This fixes the build with Python 3.12+
# https://bugzilla.redhat.com/2165572
# Upstream PR: https://github.com/libpwquality/libpwquality/pull/74
Patch1:		setuptools.patch

BuildRequires:	gettext-devel
BuildRequires:	libcrack-devel
BuildRequires:	pam-devel
BuildRequires:	pkgconfig(python3)
BuildRequires:	python3dist(setuptools)

%description
The libpwquality library purpose is to provide common functions for password
quality checking and also scoring them based on their apparent randomness.

The library also provides a function for generating random passwords with good
pronounceability. The library supports reading and parsing of a configuration
file.

%package tools
Group:		System/Base
Summary:	Tools for password quality checking and generating random passwords
Requires:	cracklib-dicts
Provides:	%{oname} = %{version}-%{release}
Provides:	%{name} = %{version}-%{release}

%description tools
The libpwquality library purpose is to provide common functions for password
quality checking and also scoring them based on their apparent randomness.

The library also provides a function for generating random passwords with good
pronounceability. The library supports reading and parsing of a configuration
file.

%package -n %{libname}
Group:		System/Libraries
Summary:	Shared libraries for %{oname}
Requires:	%{name}-tools >= %{version}-%{release}

%description -n %{libname}
The libpwquality library purpose is to provide common functions for password
quality checking and also scoring them based on their apparent randomness.

%package -n %{devname}
Group:		Development/Other
Summary:	Files needed for developing PAM-aware applications and modules for PAM
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	%{oname}-devel = %{version}-%{release}
Conflicts:	%{name}-tools < 1.3.0

%description -n %{devname}
Files needed for development of applications using the libpwquality library.

%package -n python3-pwquality
Group:		Development/Python
Summary:	Python 3 bindings for the libpwquality library
%{?python_provide:%python_provide python3-pwquality}

%description -n python3-pwquality
This is pwquality Python module that provides Python3 bindings for the
libpwquality library. These bindings can be used for easy password quality
checking and generation of random pronounceable passwords from Python
applications.

%package -n pam_%{oname}
Summary:	PAM module to perform password quality checking
Group:		System/Libraries
Provides:	pam-%{oname} = %{version}-%{release}
Conflicts:	%{name}-tools < 1.3.0
Conflicts:	%{_lib}pwquality1 < 1.3.0

%description -n pam_%{oname}
PAM module that can be used instead of pam_cracklib to disallow weak new
passwords when user's login password is changed.

%prep
%autosetup -p1

%build
#update autotool files
autoreconf -vfi
%configure \
	--with-securedir=%{_libdir}/security \
	--disable-static \
	--disable-rpath
%make_build

%install
%make_install

install -d %{buildroot}%{_sysconfdir}/security/pwquality.conf.d/

%find_lang %{name}

%files tools -f %{name}.lang
%license COPYING
%doc README NEWS AUTHORS
%config(noreplace) %{_sysconfdir}/security/%{oname}.conf
%dir %{_sysconfdir}/security/pwquality.conf.d/
%{_bindir}/pwmake
%{_bindir}/pwscore
%{_mandir}/man1/pwmake.1*
%{_mandir}/man1/pwscore.1*
%{_mandir}/man5/pwquality.conf.5*

%files -n %{libname}
%{_libdir}/%{name}.so.%{major}{,.*}

%files -n pam_%{oname}
%{_libdir}/security/pam_pwquality.so
%{_mandir}/man8/pam_pwquality.8*

%files -n %{devname}
%{_includedir}/%{oname}.h
%{_libdir}/%{name}.so
%{_libdir}/pkgconfig/%{oname}.pc
%{_mandir}/man3/pwquality.3*

%files -n python3-pwquality
%{python3_sitearch}/pwquality-%{version}-py%{python3_version}.egg-info
%{python3_sitearch}/%{oname}.*.so


%changelog
* Tue Mar 04 2025 wally <wally> 1.4.5-4.mga10
+ Revision: 2160339
- rebuild for python3.13

* Fri Apr 05 2024 wally <wally> 1.4.5-3.mga10
+ Revision: 2054646
- basesystem rebuild for i686

* Mon Feb 12 2024 daviddavid <daviddavid> 1.4.5-2.mga10
+ Revision: 2040511
- add fedora patch to use setuptools instead of distutils to fix build with py3.12
- rebuild for py3.12

* Thu Jan 05 2023 luigiwalser <luigiwalser> 1.4.5-1.mga9
+ Revision: 1930467
- 1.4.5

* Sun Aug 07 2022 wally <wally> 1.4.4-7.mga9
+ Revision: 1876011
- move python distutils fix to %%install to make it actually to work

* Tue Aug 02 2022 tv <tv> 1.4.4-6.mga9
+ Revision: 1874552
- use Python's bundled distutils as setuptools>=60 breaks havoc

* Sun Jul 31 2022 mrambo3501 <mrambo3501> 1.4.4-5.mga9
+ Revision: 1874049
- fix files list

* Sun Mar 27 2022 umeabot <umeabot> 1.4.4-4.mga9
+ Revision: 1829398
- Mageia 9 Mass Rebuild

* Tue Mar 01 2022 mrambo3501 <mrambo3501> 1.4.4-3.mga9
+ Revision: 1787121
- rebuild for python-3.10
+ wally <wally>
- drop python3 hacks
- let post %%install scriptlet remove .la files

* Mon Apr 05 2021 wally <wally> 1.4.4-2.mga9
+ Revision: 1713635
- rebuild for python 3.9

* Wed Oct 14 2020 wally <wally> 1.4.4-1.mga8
+ Revision: 1636009
- new version 1.4.4

* Mon Feb 17 2020 umeabot <umeabot> 1.4.2-2.mga8
+ Revision: 1537784
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sun Nov 10 2019 wally <wally> 1.4.2-1.mga8
+ Revision: 1459065
- new version 1.4.2

* Sat Sep 21 2019 wally <wally> 1.4.1-1.mga8
+ Revision: 1444240
- new version 1.4.1

* Wed Sep 11 2019 wally <wally> 1.4.0-4.mga8
+ Revision: 1439670
- rebuild for python3.8
- drop python2 support

* Wed Jan 09 2019 daviddavid <daviddavid> 1.4.0-3.mga7
+ Revision: 1353081
- rebuild for new Python 3.7
- rename python-pwquality to python2-pwquality

* Sun Sep 23 2018 umeabot <umeabot> 1.4.0-2.mga7
+ Revision: 1299104
- Mageia 7 Mass Rebuild

* Tue Oct 10 2017 wally <wally> 1.4.0-1.mga7
+ Revision: 1170773
- new version 1.4.0

* Sat Aug 05 2017 pterjan <pterjan> 1.3.0-5.mga7
+ Revision: 1135258
- Rebuild for python 3.6

* Thu Feb 11 2016 umeabot <umeabot> 1.3.0-4.mga6
+ Revision: 955619
- Mageia 6 Mass Rebuild

* Sat Oct 10 2015 daviddavid <daviddavid> 1.3.0-3.mga6
+ Revision: 888732
- use new python macros
+ ovitters <ovitters>
- rebuild for new python3

* Sun Jul 26 2015 wally <wally> 1.3.0-2.mga6
+ Revision: 857891
- simplify python linking fix

* Sun Jul 26 2015 wally <wally> 1.3.0-1.mga6
+ Revision: 857826
- add patch to fix python3 build
- new version 1.3.0
- add support for python3
- split out pam_pwquality
- move man pages between pkgs

* Wed Oct 15 2014 umeabot <umeabot> 1.2.4-4.mga5
+ Revision: 749450
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1.2.4-3.mga5
+ Revision: 726844
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 1.2.4-2.mga5
+ Revision: 681726
- Mageia 5 Mass Rebuild

* Thu Aug 07 2014 wally <wally> 1.2.4-1.mga5
+ Revision: 660944
- new version 1.2.4

* Sat Oct 19 2013 umeabot <umeabot> 1.2.3-2.mga4
+ Revision: 534775
- Mageia 4 Mass Rebuild

* Sat Sep 14 2013 wally <wally> 1.2.3-1.mga4
+ Revision: 478808
- new version 1.2.3

* Thu Jun 20 2013 wally <wally> 1.2.2-1.mga4
+ Revision: 445270
- new version 1.2.2

* Sat Jan 12 2013 umeabot <umeabot> 1.2.1-2.mga3
+ Revision: 358020
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Dec 22 2012 wally <wally> 1.2.1-1.mga3
+ Revision: 333820
- new version 1.2.1

* Sat Aug 25 2012 wally <wally> 1.2.0-1.mga3
+ Revision: 283859
- new version 1.2.0
- fix some paths after /usr move

* Wed Jun 27 2012 wally <wally> 1.1.1-4.mga3
+ Revision: 264482
- add libpwquality-tools require to lib pkg (to get the config file)

* Wed Jun 27 2012 wally <wally> 1.1.1-3.mga3
+ Revision: 264445
- really fix devel pkg

* Wed Jun 27 2012 wally <wally> 1.1.1-2.mga3
+ Revision: 264435
- fix devel pkg

* Wed Jun 27 2012 wally <wally> 1.1.1-1.mga3
+ Revision: 264401
- import libpwquality (based to .spec from Fedora)

